@@ -28,13 +28,15 @@
 using namespace Arts;
 using namespace std;
 
-KButtonMapper::KButtonMapper(KButton_impl *_impl, QPushButton *but)
-	: impl(_impl)
+KButtonMapper::KButtonMapper( KButton_impl *_impl, QPushButton *but )
+	: QObject( but, "KButtonMapper" )
+	, impl( _impl )
 	, button( but )
 {
 	connect( but, SIGNAL( pressed() ), this, SLOT( pressed() ) );
 	connect( but, SIGNAL( released() ), this, SLOT( released() ) );
 	connect( but, SIGNAL( toggled( bool ) ), this, SLOT( toggled( bool ) ) );
+	connect( but, SIGNAL( clicked() ), this, SLOT( clicked() ) );
 }
 
 void KButtonMapper::pressed()
@@ -55,39 +57,72 @@ void KButtonMapper::toggled( bool b )
 		impl->changeState( b );
 }
 
-KButton_impl::KButton_impl( QPushButton * _qpushbutton )
-	: KWidget_impl( _qpushbutton ? _qpushbutton : new QPushButton( 0 ) )
+void KButtonMapper::clicked()
 {
-	qpushbutton = static_cast<QPushButton*>( qwidget );
-	new KButtonMapper( this, qpushbutton );
+	impl->emitClicked();
+}
+
+KButton_impl::KButton_impl( QPushButton * widget )
+	: KWidget_impl( widget ? widget : new QPushButton( 0 ) )
+	, _clicked( false )
+{
+	_qpushbutton = static_cast<QPushButton*>( _qwidget );
+	( void )new KButtonMapper( this, _qpushbutton );
+}
+
+void KButton_impl::constructor( Widget p )
+{
+	parent( p );
+}
+
+void KButton_impl::constructor( const string & t, Widget p )
+{
+	parent( p );
+	text( t );
+}
+
+void KButton_impl::emitClicked()
+{
+	_clicked = true;
+	clicked_changed( true );
 }
 
 string KButton_impl::text()
 {
-	return qpushbutton->text().utf8().data();
+	return _qpushbutton->text().utf8().data();
 }
 
 void KButton_impl::text(const string& newText)
 {
-	qpushbutton->setText(QString::fromUtf8(newText.c_str()));
+	_qpushbutton->setText(QString::fromUtf8(newText.c_str()));
 }
 
 bool KButton_impl::toggle()
 {
-	return qpushbutton->isToggleButton();
+	return _qpushbutton->isToggleButton();
 }
 
 void KButton_impl::toggle(bool newToggle)
 {
-	qpushbutton->setToggleButton(newToggle);
+	_qpushbutton->setToggleButton(newToggle);
 }
 
 bool KButton_impl::pressed()
 {
-	if( qpushbutton->isToggleButton() )
-		return qpushbutton->isOn();
+	if( _qpushbutton->isToggleButton() )
+		return _qpushbutton->isOn();
 	else
-		return qpushbutton->isDown();
+		return _qpushbutton->isDown();
+}
+
+bool KButton_impl::clicked()
+{
+	if( _clicked )
+	{
+		_clicked = false;
+		return true;
+	}
+	return false;
 }
 
 void KButton_impl::changeState(bool newState)
