@@ -22,13 +22,14 @@
 
 #include "artsbuilder.h"
 #include "debug.h"
-#include <fstream.h>
+#include <fstream>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <dirent.h>
 #include <set>
+#include <cstring>
 
 
 using namespace Arts;
@@ -238,15 +239,18 @@ public:
 		{
 			const string& filename = *i;
 
-			struct stat st;
-			stat(filename.c_str(), &st);
-		
 			if(!first) result += ",";
 			first = false;
 
-			char mtime[32];
-			sprintf(mtime,"[%ld]",st.st_mtime);
-			result += filename + mtime;
+			struct stat st;
+			if( stat(filename.c_str(), &st) == 0 )
+			{
+				char mtime[32];
+				sprintf(mtime,"[%ld]",st.st_mtime);
+				result += filename + mtime;
+			}
+			else
+				result += filename + "[-1]";
 		}
 		return result;
 	}
