@@ -37,7 +37,7 @@ Kaboodle::Conf::Conf(QWidget *_parent, const char *_name)
 	QVBox *box = makeVBoxMainWidget();
 
 	autoPlay = new QCheckBox(i18n("Start playing automatically"), box);
-	quitAfterPlaying = new QCheckBox(i18n("Quit after finished playing"), box);
+	quitAfterPlaying = new QCheckBox(i18n("Quit when finished playing"), box);
 
 	KConfig &config = *KGlobal::config();
 	config.setGroup("core");
