@@ -30,7 +30,7 @@ K_EXPORT_COMPONENT_FACTORY( libkaboodlepart, Kaboodle::KaboodleFactory)
 KInstance *Kaboodle::KaboodleFactory::s_instance = 0;
 KAboutData *Kaboodle::KaboodleFactory::s_aboutData = 0;
 
-Kaboodle::KaboodleFactory::KaboodleFactory()
+Kaboodle::KaboodleFactory::KaboodleFactory() : KParts::Factory()
 {
 }
 
@@ -66,15 +66,16 @@ const KAboutData *Kaboodle::KaboodleFactory::aboutData()
 {
 	if(!s_aboutData)
 	{
-		s_aboutData = new KAboutData("kaboodle", I18N_NOOP("Kaboodle"), "1.61",
+		s_aboutData = new KAboutData("kaboodle", I18N_NOOP("Kaboodle"), "1.7",
 		                             I18N_NOOP("The Lean KDE Media Player"),
 		                             KAboutData::License_BSD,
-		                             "(c) 2001 Kaboodle developers", 0,
+		                             "(c) 2001-2003 Kaboodle developers", 0,
 		                             "http://www.freekde.org/neil/kaboodle/");
-		s_aboutData->addAuthor("Neil Stevens", I18N_NOOP("Maintainer"), "neil@qualityassistant.com");
-		s_aboutData->addAuthor("Nikolas Zimmermann", I18N_NOOP("Konqueror Embedding"), "wildfox@kde.org");
-		s_aboutData->addAuthor("Charles Samuels", I18N_NOOP("Original Noatun Developer"), "charles@kde.org");
+		s_aboutData->addCredit("Carsten Pfeiffer", I18N_NOOP("Maintainer"), "pfeiffer@kde.org");
+		s_aboutData->addAuthor("Neil Stevens", I18N_NOOP("Previous Maintainer"), "neil@qualityassistant.com");
 		s_aboutData->addCredit("Elhay Achiam", I18N_NOOP("Application icon"));
+		s_aboutData->addCredit("Charles Samuels", I18N_NOOP("Original Noatun Developer"), "charles@kde.org");
+		s_aboutData->addCredit("Nikolas Zimmermann", I18N_NOOP("Konqueror Embedding"), "wildfox@kde.org");
 	}
 	return s_aboutData;
 }
