@@ -15,50 +15,46 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
 #ifndef _midicfgdlg_h_
 #define _midicfgdlg_h_
 
-#include <qdialog.h>
+#include <kdialogbase.h>
 
 class DeviceManager;
 
 class QLabel;
 class QPushButton;
 class QListBox;
-class MidiConfigDialog : public QDialog
+class MidiConfigDialog : public KDialogBase
 {
-	Q_OBJECT
+  Q_OBJECT
 
 public:
 
-	MidiConfigDialog(DeviceManager *dm,QWidget *parent,const char *name);
+  MidiConfigDialog(DeviceManager *dm,QWidget *parent,const char *name);
 
 public slots:
-	void deviceselected(int idx);
-	void browseMap();
-	void noMap();
+  void deviceselected(int idx);
+  void browseMap();
+  void noMap();
 
 private:
-QLabel *label;
-QLabel *label2;
-QLabel *maplabel;
-QPushButton *ok;
-QPushButton *cancel;
-QListBox *mididevices;
-QPushButton *mapbrowse;
-QPushButton *mapnone;
+  QLabel *maplabel;
+  QListBox *mididevices;
+  QPushButton *mapbrowse;
+  QPushButton *mapnone;
 
-DeviceManager *devman;
+  DeviceManager *devman;
 
 public:
-static int selecteddevice;
-static char *selectedmap;
+  static int selecteddevice;
+  static char *selectedmap;
 };
 
 #endif
