@@ -33,6 +33,11 @@
 #include "kmix-platforms.cpp"
 #include "volume.h"
 
+//#define MIXER_MASTER_DEBUG
+
+#ifdef MIXER_MASTER_DEBUG
+#warning MIXER_MASTER_DEBUG is enabled. DO NOT SHIP KMIX LIKE THIS !!!
+#endif
 
 /**
  * Some general design hints. Hierachy is Mixer->MixDevice->Volume
@@ -85,7 +90,7 @@ Mixer::Mixer( int driver, int device ) : DCOPObject( "Mixer" )
 
   _pollingTimer = new QTimer(); // will be started on open() and stopped on close()
   connect( _pollingTimer, SIGNAL(timeout()), this, SLOT(readSetFromHW()));
- 
+
   QCString objid;
 #ifndef KMIX_DCOP_OBJID_TEST
   objid.setNum(_mixerBackend->m_devnum);
@@ -96,7 +101,7 @@ Mixer::Mixer( int driver, int device ) : DCOPObject( "Mixer" )
 #endif
   objid.prepend("Mixer");
   DCOPObject::setObjId( objid );
-  
+
 }
 
 Mixer::~Mixer() {
@@ -196,7 +201,14 @@ int Mixer::open()
 	}
       }
 	*/
-      _pollingTimer->start(50); // !!
+      if ( _mixerBackend->needsPolling() ) {
+          _pollingTimer->start(50);
+      }
+      else {
+          _mixerBackend->prepareSignalling(this);
+          // poll once to give the GUI a chance to rebuild it's info
+          QTimer::singleShot( 50, this, SLOT( readSetFromHW() ) );
+      }
       return err;
 }
 
@@ -236,6 +248,12 @@ bool Mixer::isValid() {
   return _mixerBackend->isValid();
 }
 
+bool Mixer::isOpen() const {
+    if ( _mixerBackend == 0 )
+        return false;
+    else
+        return _mixerBackend->isOpen();
+}
 
 /* ------- WRAPPER METHODS. END -------------------------------- */
 
@@ -257,6 +275,11 @@ void Mixer::readSetFromHWforceUpdate() const {
 */
 void Mixer::readSetFromHW()
 {
+  if ( ! _mixerBackend->isOpen() ) {
+     // bail out immediately, if the mixer is not open.
+     // This can happen currently only, if the user executes the DCOP close() call.
+     return;
+  }
   bool updated = _mixerBackend->prepareUpdateFromHW();
   if ( (! updated) && (! _readSetFromHWforceUpdate) ) {
     // Some drivers (ALSA) are smart. We don't need to run the following
@@ -356,12 +379,19 @@ void Mixer::setMasterCard(QString& ref_id)
 Mixer* Mixer::masterCard()
 {
   Mixer *mixer = 0;
+  kdDebug(67100) << "Mixer::masterCard() searching for id=" << _masterCard << "\n";
   for (mixer=Mixer::mixers().first(); mixer!=0; mixer=Mixer::mixers().next())
   {
      if ( mixer->id() == _masterCard ) {
+#ifdef MIXER_MASTER_DEBUG
+        kdDebug(67100) << "Mixer::masterCard() found id=" << mixer->id() << "\n";
+#endif
         break;
      }
   }
+#ifdef MIXER_MASTER_DEBUG
+  if ( mixer == 0) kdDebug(67100) << "Mixer::masterCard() found no Mixer* mixer \n";
+#endif
   return mixer;
 }
 
@@ -372,6 +402,9 @@ void Mixer::setMasterCardDevice(QString& ref_id)
   // Also you can set the master at any time you like, e.g. after reading the KMix configuration file
   // and before actually constructing the Mixer instances (hint: this mehtod is static!).
   _masterCardDevice = ref_id;
+#ifdef MIXER_MASTER_DEBUG
+   kdDebug(67100) << "Mixer::setMasterCardDevice(\"" << ref_id << "\")\n";
+#endif
 }
 
 MixDevice* Mixer::masterCardDevice()
@@ -380,15 +413,24 @@ MixDevice* Mixer::masterCardDevice()
   Mixer *mixer = masterCard();
   if ( mixer != 0 ) {
      for( md = mixer->_mixerBackend->m_mixDevices.first(); md != 0; md = mixer->_mixerBackend->m_mixDevices.next() ) {
-/*
-     	kdDebug(67100) << "Mixer::masterCardDevice() getPK()="
-     		<< md->getPK() << " , _masterCardDevice="
-     		<< _masterCardDevice << "\n";
-*/
+
+
        if ( md->getPK() == _masterCardDevice )
+        {
+#ifdef MIXER_MASTER_DEBUG
+         kdDebug(67100) << "Mixer::masterCardDevice() getPK()="
+         << md->getPK() << " , _masterCardDevice="
+         << _masterCardDevice << "\n";
+#endif
           break;
+        }
      }
   }
+
+#ifdef MIXER_MASTER_DEBUG
+  if ( md == 0) kdDebug(67100) << "Mixer::masterCardDevice() found no MixDevice* md" "\n";
+#endif
+
   return md;
 }
 
@@ -465,6 +507,7 @@ void Mixer::setVolume( int deviceidx, int percentage )
   if (!mixdev) return;
 
   Volume vol=mixdev->getVolume();
+  // @todo The next call doesn't handle negative volumes correctly.
   vol.setAllVolumes( (percentage*vol.maxVolume())/100 );
   _mixerBackend->writeVolumeToHW(deviceidx, vol);
 }
@@ -498,7 +541,25 @@ int Mixer::volume( int deviceidx )
   if (!mixdev) return 0;
 
   Volume vol=mixdev->getVolume();
-  return (vol.getVolume( Volume::LEFT )*100)/vol.maxVolume();
+  // @todo This will not work, if minVolume != 0      !!! 
+  //       e.g.: minVolume=5 or minVolume=-10
+  // The solution is to check two cases:
+  //     volume < 0 => use minVolume for volumeRange
+  //     volume > 0 => use maxVolume for volumeRange
+  //     If chosen volumeRange==0 => return 0
+  // As this is potentially used often (Sliders, ...), it
+  // should beimplemented in the Volume class. 
+
+  // For now we go with "maxVolume()", like in the rest of KMix.
+  long volumeRange = vol.maxVolume(); // -vol.minVolume() ;
+  if ( volumeRange == 0 )
+  {
+    return 0;
+  }
+  else
+  {
+     return ( vol.getVolume( Volume::LEFT )*100) / volumeRange ;
+  }
 }
 
 // @dcop , especially for use in KMilo
@@ -617,6 +678,16 @@ void Mixer::setMute( int deviceidx, bool on )
   _mixerBackend->writeVolumeToHW(deviceidx, mixdev->getVolume() );
 }
 
+// @dcop only
+void Mixer::setMasterMute( bool on )
+{
+  MixDevice *master = masterDevice();
+  if (master != 0 ) {
+    setMute( master->num(), on );
+  }
+}
+
+
 // @dcop
 void Mixer::toggleMute( int deviceidx )
 {
@@ -624,12 +695,22 @@ void Mixer::toggleMute( int deviceidx )
   if (!mixdev) return;
 
   bool previousState= mixdev->isMuted();
-  
+
   mixdev->setMuted( !previousState );
 
   _mixerBackend->writeVolumeToHW(deviceidx, mixdev->getVolume() );
 }
 
+// @dcop only
+void Mixer::toggleMasterMute()
+{
+  MixDevice *master = masterDevice();
+  if (master != 0 ) {
+    toggleMute( master->num() );
+  }
+}
+
+
 // @dcop
 bool Mixer::mute( int deviceidx )
 {
@@ -639,6 +720,17 @@ bool Mixer::mute( int deviceidx )
   return mixdev->isMuted();
 }
 
+// @dcop only
+bool Mixer::masterMute()
+{
+  MixDevice *master = masterDevice();
+  if (master != 0 ) {
+    return mute( master->num() );
+  }
+  return true;
+}
+
+
 bool Mixer::isRecordSource( int deviceidx )
 {
   MixDevice *mixdev= mixDeviceByType( deviceidx );
