@@ -1,7 +1,7 @@
 #ifndef SYNCSMTPSUBMIT_H
 #define SYNCSMTPSUBMIT_H
 /*
-  Copyright (C) 2003 Richard Lrkng <nouseforaname@home.se>
+  Copyright (C) 2003 Richard Lärkäng <nouseforaname@home.se>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -29,10 +29,8 @@ namespace KCDDB
       SyncSMTPSubmit(const QString& hostname, uint port, const QString& username,
                      const QString& from, const QString& to);
       virtual ~SyncSMTPSubmit();
-
-      virtual Result submit( const CDInfo &, const TrackOffsetList&);
     protected:
-      Result parseWrite( const QString & );
+      virtual Result runJob(KIO::Job* job);
   } ;
 }
 
