@@ -10,11 +10,13 @@
 
  */
 
+#include <config.h>
 
 #include "inputInterface.h"
 #include "multiReader.h"
+#include <iostream>
 
-
+using namespace std;
 
 InputInterface::InputInterface(){
 
@@ -73,7 +75,7 @@ int InputInterface::write(int fd,const char* txt) {
     snprintf(loopback->getData(),300,
 	     "Command:41 Msg:%s",txt);
   } else {
-    strcpy(loopback->getData(),txt);
+    strlcpy(loopback->getData(),txt, loopback->getSize());
   }
   len =loopback->len();
   back=::write(fd,loopback->getData(),len);
@@ -134,7 +136,7 @@ void InputInterface::makeValidLine(char* line) {
 	     "Command:%d Msg:%s",currentCommandNumber,line);
   } else {
     increaseCurrentCommandNumber();
-    strcpy(currentLine->getData(),line);
+    strlcpy(currentLine->getData(),line, currentLine->getSize());
   }
 
   return;
