@@ -13,6 +13,10 @@
 
 #include "performance.h"
 
+#include <iostream>
+
+using namespace std;
+
 
 Performance::Performance() {
   picCnt=0;
