@@ -15,6 +15,10 @@
 #include "syncClockMPEG.h"
 
 
+#include <iostream>
+
+using namespace std;
+
 
 SyncClockMPEG::SyncClockMPEG() {
   syncMode=__SYNC_NONE;
