@@ -5,7 +5,7 @@
 #include <kurl.h>
 #include <arts/kmedia2.h>
 #include <noatun/playlist.h>
-
+#include <kdemacros.h>
 class Visualization;
 
 namespace Arts
@@ -30,7 +30,7 @@ class NoatunApp;
  * Does almost everything related to multimedia.
  * Most interfacing should be done with Player
  **/
-class Engine : public QObject
+class KDE_EXPORT Engine : public QObject
 {
 Q_OBJECT
 friend class NoatunApp;
