@@ -10,7 +10,7 @@ public:
 	virtual ~KJWidget() {};
 	// called when the widget should paint
 	virtual void paint(QPainter *, const QRect &) {};
-	// called to recieve the rect this widget is in
+	// called to receive the rect this widget is in
 	virtual QRect rect() const { return mRect; }
 	// called when pressed in this widget
 	virtual bool mousePress(const QPoint &) {return false; }
@@ -21,11 +21,7 @@ public:
 	virtual void timeUpdate(int) {}
 	// called when a new song is playing, player() is ready with it too
 	virtual void newFile() {}
-	// called when user opened playlist
-	virtual void playlistShown(void) {}
-	// called when user closed playlist
-	virtual void playlistHidden(void) {}
-	// called when config-entries have to be read TODO
+	// called when config-entries have to be read, is a TODO for most widgets
 	virtual void readConfig() {}
 
 	// called when the mouse is moved while clicked in this widget
@@ -38,7 +34,7 @@ public:
 	static QBitmap getMask(const QImage &color, register QRgb=qRgb(255,0,255));
 
 protected:
-	QString backgroundPressed(const QString &bmp);
+	const QString &backgroundPressed(const QString &bmp) const;
 	KJLoader *parent() const {return mParent;}
 	KJLoader &parser() const {return *mParent;}
 
