@@ -19,9 +19,6 @@
 #include <pthread.h>
 #include <time.h>
 #include <sys/time.h>
-#ifndef HAVE_XINE_1
-#include <xine/xine_internal.h>
-#endif
 #include <xine/audio_out.h>
 
 #include "audio_fifo_out.h"
@@ -283,13 +280,8 @@ static int ao_fifo_control( ao_driver_t *this_gen, int cmd, ... )
     return 0;
 }
 
-#ifdef HAVE_XINE_1
 xine_audio_port_t *init_audio_out_plugin( xine_t *xine, xine_arts_audio *audio,
 					  void **ao_driver )
-#else
-ao_driver_t *init_audio_out_plugin( xine_t *xine, xine_arts_audio *audio,
-				    void **ao_driver )
-#endif
 {
     fifo_driver_t *ao = (fifo_driver_t *)malloc( sizeof(fifo_driver_t) );
 
@@ -320,11 +312,7 @@ ao_driver_t *init_audio_out_plugin( xine_t *xine, xine_arts_audio *audio,
 
     *ao_driver		= (void *)ao;
 
-#ifdef HAVE_XINE_1
-    return ao_new_port( xine, (ao_driver_t *)ao, 0 );
-#else
-    return (ao_driver_t *)ao;
-#endif
+    return _x_ao_new_port( xine, (ao_driver_t *)ao, 0 );
 }
 
 unsigned long ao_fifo_read( void *ao_driver, unsigned char **buffer,
